@@ -90,7 +90,7 @@ Popup Events
 There are two events available: `on_open` which is raised when the popup is
 opening, and `on_dismiss` which is raised when the popup is closed.
 For `on_dismiss`, you can prevent the
-popup from closing by explictly returning True from your callback::
+popup from closing by explicitly returning True from your callback::
 
     def my_callback(instance):
         print('Popup', instance, 'is being dismissed but is prevented!')
@@ -210,14 +210,14 @@ class Popup(ModalView):
 
     _container = ObjectProperty(None)
 
-    def add_widget(self, widget):
+    def add_widget(self, widget, *args, **kwargs):
         if self._container:
             if self.content:
                 raise PopupException(
                     'Popup can have only one widget as content')
             self.content = widget
         else:
-            super(Popup, self).add_widget(widget)
+            super(Popup, self).add_widget(widget, *args, **kwargs)
 
     def on_content(self, instance, value):
         if self._container:
